#!/bin/bash
#
# Enable WLAN on Campark T85
# author timm@ganske.org 2022
# many thanks to Rolf Schatzmann rolf@rolf.id.au for providing information how to do
# using Bluetooth configuration to send command
#
# Parameter 1 ON or OFF
# Parameter 2 (optional) Search string for correct MAC Addr in bluetoothctl Devices

HANDLE="0x002e"
WIFION="4750494f33"
WIFIOFF="4750494f32"

[[ -z "$T85GATTTIMEOUT" ]] && T85GATTTIMEOUT=15
[[ -z "$T85GATTSLEEPAFTER" ]] && T85GATTSLEEPAFTER=5

case "$1" in
  "ON")
    WIFICMD="$WIFION"
    CMDTEXT="enable"
  ;;
  "OFF")
    WIFICMD="$WIFIOFF"
    CMDTEXT="disable"
  ;;
  *)
    echo "usage: $0 CMD [Wildcard]"
    echo "    CMD is ON or OFF"
    echo "    Wildcard is grep string for bluetoothctl devices"
    echo "            (Default ^Device 62:00:)"
    exit 0
  ;;
esac


if [[ -z "$T85BLUEMACADDR" ]]; then
  
  # parameter 1 is Devicename T85 Bluetooth search for grep
  [ "$2" ] && T85BLUESEARCH="$2"
  [ -z "$T85BLUESEARCH" ] && T85BLUESEARCH="^Device 62:00:"

  available=$(bluetoothctl devices)
  [ "$T85DBG" ] && echo "Available Bluetooth devices :"
  [ "$T85DBG" ] && echo "$available"

  camdevice=$(echo "$available" | grep "$T85BLUESEARCH")
  now=$(date +"%Y%m%d_%H%M%S")
  [ "$T85DBG" ] && echo "$now dbg found /$camdevice/"

  now=$(date +"%Y%m%d_%H%M%S")
  lines=$(echo "$camdevice" | wc -l)
  if [[ $lines == 1 ]]; then
    [ "$T85DBG" ] && echo "$now dbg exactly one device found /$camdevice/"
    T85BLUEMACADDR="${camdevice:7:17}"
  else
    echo "$now not sure which Bluetooth device is to $CMDTEXT, found $camdevice with $lines lines"
  fi
fi

if [[ "$T85BLUEMACADDR" ]]; then
  now=$(date +"%Y%m%d_%H%M%S")
  echo "$now Bluetooth device to $CMDTEXT has MAC Address $T85BLUEMACADDR"
  [ "$T85DBG" ] && echo "$now dbg call gatttool for $T85BLUEMACADDR $WIFICMD"
  result=$(timeout $T85GATTTIMEOUT gatttool -b $T85BLUEMACADDR --char-write-req -a $HANDLE -n $WIFICMD --listen)
  now=$(date +"%Y%m%d_%H%M%S")
  [[ "$result" != "Characteristic value was written successfully" ]] && echo "$now result NOK $result" || sleep $T85GATTSLEEPAFTER
else
  now=$(date +"%Y%m%d_%H%M%S")
  [ "$T85DBG" ] && echo "$now dbg macaddr not set $T85BLUEMACADDR"
  echo "$now WLAN T85 $CMDTEXT: please connect Bluetooth using Android-App Hunting Camera Pro and $CMDTEXT WLAN"
fi

