#!/bin/bash
# Get and (after successful transfer) remove a file on Campark T85 camera
# author timm@ganske.org 2020
# Check that the file is fine according to Content-Length given in headers
# Parameters: Filename filelink removelink
#

filename=$1
filelink=$2
removelink=$3

# this way it is possible to set T85minfilesize default from environment
[ -z "$T85minfilesize" ] && T85minfilesize=10240

[ -z "$T85curltimeout" ] && T85curltimeout=29
if [ -z "$T85curlopt" ]; then
  [ "$T85DBG" ] && T85curlopt="-m $T85curltimeout" || T85curlopt="-s -S -m $T85curltimeout"
fi

now=$(date +"%Y%m%d_%H%M%S")
[ "$T85DBG" ] && echo dbg $now T85getfile called, parameters $*

fileinfo=$(curl $T85curlopt -I $filelink)

result=$?
if [ $result != 0 ]; then
  now=$(date +"%Y%m%d_%H%M%S")
  echo $now curl fileinfo error result $result
  exit $result
fi

[ "$T85DBG" ] && echo dbg Info is -- start --
[ "$T85DBG" ] && echo dbg $fileinfo
[ "$T85DBG" ] && echo dbg Info is -- end --

while read -r infoline; do
[ "$T85DBG" ] && echo dbg checking line $infoline
  if [[ "$infoline" == "Content-Type: image/jpeg"* ]]; then
    filetype="jpeg"
    [ "$T85DBG" ] && echo dbg filetype jpeg found
  fi 
  if [[ "$infoline" == "Content-Type: application/octet-stream"* ]]; then
    filetype="movie"
    [ "$T85DBG" ] && echo dbg filetype movie found
  fi 
  if [[ "$infoline" == "Content-Length:"* ]]; then
    unset filesize
    filesize=${infoline:16}
    filesize=$(echo $filesize | tr -d '\r\n')
    [ "$T85DBG" ] && echo dbg size is /$filesize/
  fi
done < <(echo "$fileinfo")
#done < <(curl $T85curlopt -I $filelink)

if [[ "$filesize" == "" ]]; then
  now=$(date +"%Y%m%d_%H%M%S")
  echo $now filesize for file $filename is empty?!?
  exit 2
else
  if (( $filesize > $T85minfilesize )); then
    if [ "$filetype" != "" ]; then
      now=$(date +"%Y%m%d_%H%M%S")
      [ "$T85DBG" ] && echo dbg $now fetch $filelink of type $filetype size $filesize into $filename
      curl $T85curlopt -o $filename $filelink
      disksize=$(stat -c%s $filename)
      [ "$T85DBG" ] && echo dbg size on disk is $disksize
      if [[ $disksize == $filesize ]]; then
        [ "$T85DBG" ] && echo dbg file $filename download ok $filesize bytes, remove it
        [ "$T85DBG" ] && echo dbg curl $removelink
        if [ "$T85DBG" ]; then
          curl $T85curlopt $removelink
        else
	  curl $T85curlopt $removelink -o /dev/null
	fi
	result=$?
        if [ $result != 0 ]; then
          now=$(date +"%Y%m%d_%H%M%S")
          echo $now curl del $removelink result $result
        fi
        [ "$T85DBG" ] && echo
      else
        now=$(date +"%Y%m%d_%H%M%S")
        echo $now file $filename download failed $disksize bytes, should be $filesize bytes. Remove it from HD, stays on cam
        rm $filename
        exit 98
      fi
    else
      [ "$T85DBG" ] && echo dbg filetype $filetype no action on $filename
    fi
  else
    now=$(date +"%Y%m%d_%H%M%S")
    echo $now file too small $filename is $filesize bytes, no file smaller than $T85minfilesize bytes is accepted
    exit 99
  fi
fi

exit 0
