#!/bin/bash
# Call to enable WLAN in parameter 1
# description in $2 is optional
# password in $3 being used if given
# exit 0 if given WLAN is active
# author timm@ganske.org 2020

WLANNAME=Campark-
# parameter 1 is Name of WLAN, may be only partial
[ "$1" ] && WLANNAME=$1

WLANDESC=WLAN
# parameter 2 is description of WLAN for output
[ "$2" ] && WLANDESC=$2

[ "$T85WSCANSLEEPAFTER" ] || T85WSCANSLEEPAFTER=5

WLANPASS=$3

if [[ "$WLANNAME" == "NUL" ]]; then
  [ "$T85DBG" ] && echo dbg WLANNAME NUL, no action
  exit 0
fi

now=$(date +"%Y%m%d_%H%M%S")

active=$(nmcli -t -f name connection show --active)
[ "$T85DBG" ] && echo dbg currently active !$active! 
if [[ "$active" = *"$WLANNAME"* ]]; then
  echo "$now $WLANDESC -$WLANNAME- is active -$active-"
  exit 0
else
  nmcli con down "$active"
  if [[ -n "$WLANNAME" ]]; then
    WLANLIST=$(nmcli device wifi list)
    [ "$T85DBG" ] && echo "dbg WLANLIST orig !$WLANLIST!"
    WLANFOUND=$(echo $WLANLIST|grep -oh "[^ ]*$WLANNAME[^ ]*" |head -n 1)
    if [ "${WLANFOUND}" == "" ]; then
      [ "$T85DBG" ] && echo "dbg not found in first list !$WLANNAME!, do rescan"
      nmcli device wifi rescan
      result=$?
      if [ $result != 0 ]; then
        echo nmcli rescan wifi result $result
      else
        [ "$T85DBG" ] && echo dbg nmcli device wifi recan !ok!
        sleep $T85WSCANSLEEPAFTER
      fi

      WLANLIST=$(nmcli device wifi list)
      [ "$T85DBG" ] && echo "dbg WLANLIST 2nd !$WLANLIST!"
      WLANFOUND=$(echo $WLANLIST|grep -oh "[^ ]*$WLANNAME[^ ]*" | head -n1)
      if [ "${WLANFOUND}" == "" ]; then
        echo WLAN $WLANDESC $WLANNAME not found despite rescan
        exit 3
      else
       [ "$T85DBG" ] && echo dbg WLANFOUND is $WLANFOUND
      fi
    fi
  
    if [ -z $WLANPASS ]; then
      echo Activating $WLANDESC $WLANFOUND
      nmcli device wifi connect $WLANFOUND
    else
      echo Activating $WLANDESC $WLANFOUND !pwd given!
      nmcli device wifi connect $WLANFOUND password $WLANPASS
    fi
    result=$?
    if [ $result != 0 ]; then
      echo nmcli set wlan $WLANDESC $WLANFOUND result $result
    else
      [ "$T85DBG" ] && echo dbg nmcli device wifi connect $WLANFOUND !ok!
    fi
    exit $result
  else
    [ "$T85DBG" ] && echo no WLAN active when started and keepWLANasis set - keep no connection
  fi  
fi

